================
Utility and View
================

Utility commands are used to do the following:

- Create SymbolicConstant and Boolean objects.
- Change the name of a key to a Repository object.
- Control the use of deprecated commands.
- Request input from the user.
- Display status information.
- Execute Python commands or functions.
- Register a callback that will be invoked when certain Abaqus Scripting Interface commands are about to be executed.
- Register a callback that will be invoked when certain Abaqus Scripting Interface objects are about to be deleted.
- Upgrade Abaqus kernel or GUI scripts from one release of Abaqus to a later release.

View commands are used to transform three-dimensional views stored in Session and Viewport objects to the screen. (See Session object and Viewport object.)


Classes
-------

AbaqusBoolean
~~~~~~~~~~~~~

.. autoclass:: abaqus.UtilityAndView.AbaqusBoolean.AbaqusBoolean
    :members:
    :special-members: __init__

    .. autoclasstoc::

BackwardCompatibility
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.UtilityAndView.BackwardCompatibility.BackwardCompatibility
    :members:
    :special-members: __init__

    .. autoclasstoc::

Callback
~~~~~~~~

.. automodule:: abaqus.UtilityAndView.Callback
    :members:
    :special-members: __init__

Customization
~~~~~~~~~~~~~

.. automodule:: abaqus.UtilityAndView.Customization
    :members:
    :special-members: __init__

Delete
~~~~~~

.. automodule:: abaqus.UtilityAndView.Delete
    :members:
    :special-members: __init__

Method
~~~~~~

.. automodule:: abaqus.UtilityAndView.Method
    :members:
    :special-members: __init__

Repository
~~~~~~~~~~

.. autoclass:: abaqus.UtilityAndView.Repository.Repository
    :members:
    :special-members: __init__

    .. autoclasstoc::

Status
~~~~~~

.. automodule:: abaqus.UtilityAndView.Status
    :members:
    :special-members: __init__

SymbolicConstant
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.UtilityAndView.SymbolicConstant.SymbolicConstant
    :members:
    :special-members: __init__

    .. autoclasstoc::

Upgrade
~~~~~~~

.. automodule:: abaqus.UtilityAndView.Upgrade
    :members:
    :special-members: __init__

User
~~~~

.. automodule:: abaqus.UtilityAndView.User
    :members:
    :special-members: __init__

View
~~~~

.. autoclass:: abaqus.UtilityAndView.View.View
    :members:
    :special-members: __init__

    .. autoclasstoc::

